@@ -1,4 +1,4 @@
 from loguru import logger as log
 from .mq import MessageQueue, Message, Resource, Response, Executor, Job, Jobs
-from .mod_resources import JSONResource
+from .pkg_resources import JSONResource, JSONLResource
 from .pkg_ezapi import RequestMessageQueue, RequestJob, RequestHash, RequestJobs, APIClient, APICache, CacheEntry
\ No newline at end of file
