@@ -292,6 +292,11 @@ class Response(AnnotatedDict):
     error: str
     result: Any
 
+# TODO: Documentation
+class BatchResponse(AnnotatedDict):
+    responses: dict[str, Response]
+    timed_out: dict[str, Response]
+
 
 class Executor:
     """
@@ -605,8 +610,7 @@ class MessageQueue:
             message_ids[key] = message_id
         return message_ids
 
-    def batch_receive(self, message_ids: dict[str, UUID], min_timeout: float = 1.0, max_iteration: int = 10) -> tuple[
-        dict[str, Response], dict[str, Response]]:
+    def batch_receive(self, message_ids: dict[str, UUID], min_timeout: float = 1.0, max_iteration: int = 10) -> BatchResponse:
         attempt_tracker = {key: 0 for key in message_ids.keys()}
         pending_responses: dict[str, Response | None] = {key: None for key in message_ids.keys()}
         responses: dict[str, Response] = {}
@@ -634,7 +638,10 @@ class MessageQueue:
                 if not any(r is None for r in pending_responses.values()):
                     break
 
-        return responses, timed_out
+        return BatchResponse(
+            responses = responses,
+            timed_out = timed_out,
+        )
 
-    def batch_send_and_receive(self, messages: dict[str, Message], min_timeout: float = 1.0, max_iteration: int = 10) -> tuple[dict[str, Response], dict[str, Response]]:
+    def batch_send_and_receive(self, messages: dict[str, Message], min_timeout: float = 1.0, max_iteration: int = 10) -> BatchResponse:
         return self.batch_receive(self.batch_send(messages), min_timeout=min_timeout, max_iteration=max_iteration)
\ No newline at end of file
